linux-fsdevel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH 1/2] iomap: Add a page_prepare callback
@ 2019-04-24 17:18 Andreas Gruenbacher
  2019-04-24 17:18 ` [PATCH 2/2] gfs2: Fix iomap write page reclaim deadlock Andreas Gruenbacher
                   ` (2 more replies)
  0 siblings, 3 replies; 6+ messages in thread
From: Andreas Gruenbacher @ 2019-04-24 17:18 UTC (permalink / raw)
  To: cluster-devel, Christoph Hellwig
  Cc: Bob Peterson, Jan Kara, Dave Chinner, Ross Lagerwall, Mark Syms,
	Edwin Török, linux-fsdevel, linux-mm,
	Andreas Gruenbacher

Add a page_prepare calback that's called before a page is written to.  This
will be used by gfs2 to start a transaction in page_prepare and end it in
page_done.  Other filesystems that implement data journaling will require the
same kind of mechanism.

Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
---
 fs/iomap.c            | 4 ++++
 include/linux/iomap.h | 9 ++++++---
 2 files changed, 10 insertions(+), 3 deletions(-)

diff --git a/fs/iomap.c b/fs/iomap.c
index 97cb9d486a7d..abd9aa76dbd1 100644
--- a/fs/iomap.c
+++ b/fs/iomap.c
@@ -684,6 +684,10 @@ iomap_write_begin(struct inode *inode, loff_t pos, unsigned len, unsigned flags,
 		status = __block_write_begin_int(page, pos, len, NULL, iomap);
 	else
 		status = __iomap_write_begin(inode, pos, len, page, iomap);
+
+	if (likely(!status) && iomap->page_prepare)
+		status = iomap->page_prepare(inode, pos, len, page, iomap);
+
 	if (unlikely(status)) {
 		unlock_page(page);
 		put_page(page);
diff --git a/include/linux/iomap.h b/include/linux/iomap.h
index 0fefb5455bda..0982f3e13e56 100644
--- a/include/linux/iomap.h
+++ b/include/linux/iomap.h
@@ -65,10 +65,13 @@ struct iomap {
 	void			*private; /* filesystem private */
 
 	/*
 	 * Called when finished processing a page in the mapping returned in
 	 * this iomap.  At least for now this is only supported in the buffered
 	 * write path.
 	 */
+	int (*page_prepare)(struct inode *inode, loff_t pos, unsigned len,
+			struct page *page, struct iomap *iomap);
 	void (*page_done)(struct inode *inode, loff_t pos, unsigned copied,
 			struct page *page, struct iomap *iomap);
 };
@@ -65,10 +65,13 @@ struct iomap {
 
 	/*
-	 * Called when finished processing a page in the mapping returned in
-	 * this iomap.  At least for now this is only supported in the buffered
-	 * write path.
+	 * Called before / after processing a page in the mapping returned in
+	 * this iomap.  At least for now, this is only supported in the
+	 * buffered write path.  When page_prepare returns 0 for a page,
+	 * page_done is called for that page as well.
 	 */
-- 
2.20.1


^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2019-04-25 15:26 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-04-24 17:18 [PATCH 1/2] iomap: Add a page_prepare callback Andreas Gruenbacher
2019-04-24 17:18 ` [PATCH 2/2] gfs2: Fix iomap write page reclaim deadlock Andreas Gruenbacher
2019-04-25  7:59 ` [PATCH 1/2] iomap: Add a page_prepare callback Christoph Hellwig
2019-04-25  8:32 ` Jan Kara
2019-04-25 15:03   ` Christoph Hellwig
2019-04-25 15:26   ` Andreas Gruenbacher

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).